@@ -3,6 +3,8 @@
 #' This class defines some resources at dbpedia.
 #' See \code{queries(dbpedia())} for a list of resources.
 #'
+#' @seealso \code{\link{dbpedia}}, \code{\link{xsparql}}
+#'
 #' @examples
 #' \dontrun{
 #'   dbp <- dbpedia()
@@ -23,63 +25,35 @@ setClass(Class="Dbpedia", representation=representation(), contains="Xsparql")
 #' @return a Dbpedia object, inherited from Xsparql
 #' @export
 #' @rdname Dbpedia-class
-dbpedia <- function(lang="") {
-    res <- new("Dbpedia",
-        url=paste("http://", lang, if(lang!="") ".", "dbpedia.org/sparql", sep=""),
-        nspace=c("dbo", "<http://dbpedia.org/ontology/>",
-             "rdf", "<http://xmlns.com/foaf/0.1>",
-             "rdfs", "<http://www.w3.org/2000/01/rdf-schema#>",
-             "owl", "<http://www.w3.org/2002/07/owl#>",
-             "xsd", "<http://www.w3.org/2001/XMLSchema#>",
-             "dc", "<http://purl.org/dc/elements/1.1/>",
-             "foaf", "<http://xmlns.com/foaf/0.1/>",
-             #"", "<http://dbpedia.org/resource/>", 
-             "dbpedia2", "<http://dbpedia.org/property/>", 
-             "dbpedia", "<http://dbpedia.org/>",
-             "skos", "<http://www.w3.org/2004/02/skos/core#>"             
-             )
-    )
-    return(res)
-}
-
-#' @rdname query-methods
-#' @name query
-#' @export
-#' @docType methods
-#' @aliases query query,Dbpedia,Nuts1-method
-setMethod(
-  f="query",
-  signature=c(self="Dbpedia", resource=resource("Nuts1")),
-  definition=function(self, resource, verbose=getOption("verbose"), ...) {
-    if(verbose) cat("query Dbpedia#Nuts1\n")
-    stmt <- paste(
-      "SELECT ?name, ?nuts, ?popDate, ?pop, ?area, ?gdp, ?popMetro WHERE {",
-      "  ?s a <http://dbpedia.org/class/yago/StatesOfGermany>;",
-      "     <http://dbpedia.org/property/nuts> ?nuts;",
-      "     rdfs:label ?name . ",
-      "  OPTIONAL { ?s <http://dbpedia.org/ontology/populationAsOf> ?popDate }",
-      "  OPTIONAL { ?s <http://dbpedia.org/property/population> ?pop }",
-      "  OPTIONAL { ?s <http://dbpedia.org/property/popMetro> ?popMetro }",
-      "  OPTIONAL { ?s <http://dbpedia.org/property/gdp> ?gdp }",
-      "  OPTIONAL { ?s <http://dbpedia.org/ontology/areaTotal> ?area } . ",
-      "  FILTER (LANG(?name)='de') } ",
-      sep=""
-    )
-    query(self, resource=stmt, verbose=verbose, ...)
-  }
-)
-
-#' @rdname query-methods
-#' @name query
-#' @export
-#' @docType methods
-#' @aliases query query,Dbpedia,PlzAgs-method
-setMethod(
-  f="query",
-  signature=c(self="Dbpedia", resource=resource("PlzAgs")),
-  definition=function(self, resource, verbose=getOption("verbose"), ...) {
-    if(verbose) cat("query Dbpedia#PlzAgs\n")
-    stmt <- paste(
+dbpedia <- function(lang="") xsparql(
+    url=paste("http://", lang, if(lang!="") ".", "dbpedia.org/sparql", sep=""),
+    nspace=c("dbo", "<http://dbpedia.org/ontology/>",
+        "rdf", "<http://xmlns.com/foaf/0.1>",
+        "rdfs", "<http://www.w3.org/2000/01/rdf-schema#>",
+        "owl", "<http://www.w3.org/2002/07/owl#>",
+        "xsd", "<http://www.w3.org/2001/XMLSchema#>",
+        "dc", "<http://purl.org/dc/elements/1.1/>",
+        "foaf", "<http://xmlns.com/foaf/0.1/>",
+        #"", "<http://dbpedia.org/resource/>", 
+        "dbpedia2", "<http://dbpedia.org/property/>", 
+        "dbpedia", "<http://dbpedia.org/>",
+        "skos", "<http://www.w3.org/2004/02/skos/core#>"             
+    ),
+    clss="Dbpedia",
+    Nuts1=paste(
+        "SELECT ?name, ?nuts, ?popDate, ?pop, ?area, ?gdp, ?popMetro WHERE {",
+        "  ?s a <http://dbpedia.org/class/yago/StatesOfGermany>;",
+        "     <http://dbpedia.org/property/nuts> ?nuts;",
+        "     rdfs:label ?name . ",
+        "  OPTIONAL { ?s <http://dbpedia.org/ontology/populationAsOf> ?popDate }",
+        "  OPTIONAL { ?s <http://dbpedia.org/property/population> ?pop }",
+        "  OPTIONAL { ?s <http://dbpedia.org/property/popMetro> ?popMetro }",
+        "  OPTIONAL { ?s <http://dbpedia.org/property/gdp> ?gdp }",
+        "  OPTIONAL { ?s <http://dbpedia.org/ontology/areaTotal> ?area } . ",
+        "  FILTER (LANG(?name)='de') } ",
+        sep=""
+    ), 
+    PlzAgs=paste(
       "SELECT ?name, ?plz, ?ags, ?tel, ?kfz WHERE {",
       "  ?s <http://de.dbpedia.org/property/wikiPageUsesTemplate> <http://de.dbpedia.org/resource/Vorlage:Infobox_Gemeinde_in_Deutschland> .",
       "  ?s <http://de.dbpedia.org/property/name> ?name .",
@@ -90,11 +64,6 @@ setMethod(
       "  FILTER (LANG(?name)='de') } LIMIT 20",
       sep="\n"
     )
-    if(verbose) cat(stmt,"\n")
-    ret <- query(self, resource=stmt, verbose=verbose, ...)
-    #todo manche plz sind durch \023 getrennt ==> Bereich!
-    return(ret)
-  }
 )
 
 
